@@ -19,7 +19,6 @@ import java.awt.Cursor;
 import java.awt.Graphics;
 import java.awt.Graphics2D;
 import java.awt.Polygon;
-import java.awt.Rectangle;
 import java.awt.RenderingHints;
 import java.awt.Stroke;
 import java.awt.event.ComponentEvent;
@@ -40,6 +39,7 @@ import javax.swing.SwingUtilities;
 import org.locationtech.jts.geom.Coordinate;
 import org.locationtech.jts.geom.Envelope;
 import org.locationtech.jts.geom.Geometry;
+import org.locationtech.jts.geom.util.AffineTransformation;
 import org.locationtech.jtstest.testbuilder.model.DisplayParameters;
 import org.locationtech.jtstest.testbuilder.model.GeometryEditModel;
 import org.locationtech.jtstest.testbuilder.model.GeometryStretcherView;
@@ -567,10 +567,12 @@ public class GeometryEditPanel extends JPanel
   
   class GeometryEditPanelRenderer implements Renderer
   {
+    private static final double LAYER_SHIFT_GUTTER_FACTOR = 0.3;
     private GeometryStretcherView stretchView = null;
   	private Renderer currentRenderer = null;
     private boolean isRevealingTopology = false; 
-    private boolean isRenderingStretchVertices = false; 
+    private boolean isRenderingStretchVertices = false;
+    private double layerShiftX; 
     
   	public GeometryEditPanelRenderer()
   	{
@@ -606,9 +608,10 @@ public class GeometryEditPanel extends JPanel
       if (viewStyle.isBorderEnabled()) {
         drawBorder(g2, viewStyle.getBorderColor());
       }
+      layerShiftX = computeLayerShift(tbModel.getLayersAll());
       
       renderLayersTheme(tbModel.getLayersBase(), g2);
-      renderLayers(getLayerList(), true, g2);
+      renderLayersCore(getLayerList(), g2);
       renderLayersTheme(tbModel.getLayersTop(), g2);
       
       if (isRevealingTopology && isRenderingStretchVertices) {
@@ -623,6 +626,7 @@ public class GeometryEditPanel extends JPanel
       
       if (viewStyle.isLegendEnabled()) {
         legendElement.setBorderEnabled(viewStyle.isLegendBorderEnabled());
+        legendElement.setStatsEnabled(viewStyle.isLegendStatsEnabled());
         legendElement.setBorderColor(viewStyle.getBorderColor());
         legendElement.setFill(viewStyle.getLegendFill());
         legendElement.paint(tbModel.getLayersLegend(), g2);
@@ -634,15 +638,35 @@ public class GeometryEditPanel extends JPanel
         titleElement.setTitle(viewStyle.getTitle());
         titleElement.paint(g2);
       }
-      
     }
     
-    private void renderLayers(LayerList layerList, boolean allowRevealTopo, Graphics2D g)
+    private double computeLayerShift(LayerList lyrList) {
+      Envelope envBase = computeLayersEnv(lyrList, false);
+      Envelope envShifted = computeLayersEnv(lyrList, true);
+      if (envShifted.isNull()) 
+        return 0;
+      double offsetX = envBase.getMaxX() - envShifted.getMinX();
+      return (1 + LAYER_SHIFT_GUTTER_FACTOR) * offsetX;
+    }
+    
+    private Envelope computeLayersEnv(LayerList lyrList, boolean isShifted) {
+      Envelope env = new Envelope();
+      int n = lyrList.size();
+      for (int i = 0; i < n; i++) {
+        Layer layer = lyrList.getLayer(i);
+        if (isShifted == layer.getLayerStyle().isShifted()) {
+          env.expandToInclude(layer.getEnvelope());
+        }
+      }
+      return env;
+    }
+    
+    private void renderLayersCore(LayerList layerList, Graphics2D g)
     {
       int n = layerList.size();
       for (int i = 0; i < n; i++) {
         Layer layer = layerList.getLayer(i);
-        currentRenderer = createRenderer(layer, i, allowRevealTopo);
+        currentRenderer = createRendererCore(layer, i);
         currentRenderer.render(g);
       }
       currentRenderer = null;
@@ -653,23 +677,37 @@ public class GeometryEditPanel extends JPanel
       int n = layerList.size();
       for (int i = n - 1; i >= 0; i--) {
         Layer layer = layerList.getLayer(i);
-        currentRenderer = createRenderer(layer, i, false);
+        currentRenderer = createRenderer(layer);
         currentRenderer.render(g);
       }
       currentRenderer = null;
     }
 
-    private Renderer createRenderer(Layer layer, int i, boolean isAllowRevealTopo) {
-      if (isAllowRevealTopo && isRevealingTopology && isRenderingStretchVertices
+    private Renderer createRendererCore(Layer layer, int i) {
+      if (isRevealingTopology && isRenderingStretchVertices
           && stretchView != null && i < 2) {
         //System.out.println("rendering stretch verts");
-      	return new LayerRenderer(layer,
-      			new StaticGeometryContainer(stretchView.getStretchedGeometry(i)),
-      			viewport);
+        return new LayerRenderer(layer,
+            new StaticGeometryContainer(stretchView.getStretchedGeometry(i)),
+            viewport);
       }
-      else {
-      	return new LayerRenderer(layer, viewport);
+      return createRenderer(layer);
+    }
+
+    private Geometry offsetGeometry(Geometry geom, double offsetX) {
+      if (geom == null) return null;
+      AffineTransformation trans = AffineTransformation.translationInstance(offsetX, 0);
+      return trans.transform(geom); 
+    }
+
+    private Renderer createRenderer(Layer layer) {
+      if (layerShiftX > 0 
+          && layer.getLayerStyle().isShifted()) {
+        return new LayerRenderer(layer,
+            new StaticGeometryContainer(offsetGeometry(layer.getGeometry(), layerShiftX)),
+            viewport);
       }
+      return new LayerRenderer(layer, viewport);
     }
     
     public void renderMagnifiedVertices(Graphics2D g)
