@@ -45,10 +45,12 @@ import org.locationtech.jtstest.testbuilder.ui.SwingUtil;
 import org.locationtech.jtstest.testbuilder.ui.style.BasicStyle;
 import org.locationtech.jtstest.testbuilder.ui.style.LayerStyle;
 import org.locationtech.jtstest.testbuilder.ui.style.Palette;
+import org.locationtech.jtstest.testbuilder.ui.style.VertexStyle;
 
 public class LayerStylePanel extends JPanel {
   private Layer layer;
   private JLabel title;
+  private JCheckBox cbShift;
   private JPanel stylePanel;
   private int rowIndex;
   private JCheckBox cbDashed;
@@ -62,12 +64,12 @@ public class LayerStylePanel extends JPanel {
   
   private JCheckBox cbVertex;
   private JPanel btnVertexColor;
-  private JSpinner spinnerVertexSize;
+  private JSpinner spinVertexSize;
   private SpinnerNumberModel vertexSizeModel;
   
   private JCheckBox cbLabel;
   private JPanel btnLabelColor;
-  private JSpinner spinnerLabelSize;
+  private JSpinner spinLabelSize;
   private SpinnerNumberModel labelSizeModel;
   
   private JCheckBox cbStroked;
@@ -76,10 +78,12 @@ public class LayerStylePanel extends JPanel {
   private JCheckBox cbStructure;
   private JCheckBox cbVertexLabel;
   private JCheckBox cbOffset;
-  private JSpinner spinnerOffsetSize;
+  private JSpinner spinOffsetSize;
   private SpinnerNumberModel offsetSizeModel;
   private JCheckBox cbEndpoint;
   private JComboBox comboPalette;
+  private JCheckBox cbSegIndex;
+  private JComboBox comboVertexSymbol;
 
   
   public LayerStylePanel() {
@@ -100,8 +104,10 @@ public class LayerStylePanel extends JPanel {
     txtName.setEditable(isModifiable);
     txtName.setFocusable(isModifiable);
 
+    cbShift.setSelected(layer.getLayerStyle().isShifted());
     cbVertex.setSelected(layer.getLayerStyle().isVertices());
     cbVertexLabel.setSelected(layer.getLayerStyle().isVertexLabels());
+    setVertexSymbol(comboVertexSymbol, layer.getLayerStyle().getVertexSymbol());
     vertexSizeModel.setValue(layer.getLayerStyle().getVertexSize());
     cbLabel.setSelected(layer.getLayerStyle().isLabel());
     labelSizeModel.setValue(layer.getLayerStyle().getLabelSize());
@@ -112,7 +118,8 @@ public class LayerStylePanel extends JPanel {
     cbStroked.setSelected(geomStyle().isStroked());
     cbFilled.setSelected(geomStyle().isFilled());
     cbOrient.setSelected(layer.getLayerStyle().isOrientations());
-    cbStructure.setSelected(layer.getLayerStyle().isOrientations());
+    cbStructure.setSelected(layer.getLayerStyle().isStructure());
+    cbSegIndex.setSelected(layer.getLayerStyle().isSegIndex());
     lineWidthModel.setValue((double) geomStyle().getStrokeWidth());
     setPaletteType(comboPalette, layer.getLayerStyle().getFillType());
     updateStyleControls();
@@ -175,7 +182,20 @@ public class LayerStylePanel extends JPanel {
     txtName.setMaximumSize(new Dimension(100,20));
     txtName.setPreferredSize(new Dimension(100,20));
     txtName.setMinimumSize(new Dimension(100,20));
-    addRow("Name", txtName);
+    
+    cbShift = new JCheckBox();
+    cbShift.setToolTipText(AppStrings.TIP_STYLE_SHIFT);
+    cbShift.setAlignmentX(Component.LEFT_ALIGNMENT);
+    cbShift.setText("Shift");
+    cbShift.addActionListener(new java.awt.event.ActionListener() {
+      public void actionPerformed(ActionEvent e) {
+        if (layer == null) return;
+        layer.getLayerStyle().setShift(cbShift.isSelected());
+        JTSTestBuilder.controller().geometryViewChanged();
+      }
+    });
+
+    addRow("Name", txtName, cbShift);
     
     txtName.getDocument().addDocumentListener(new DocumentListener() {
       public void changedUpdate(DocumentEvent e) {
@@ -220,10 +240,10 @@ public class LayerStylePanel extends JPanel {
        );
     
     vertexSizeModel = new SpinnerNumberModel(4, 0, 100, 1);
-    spinnerVertexSize = new JSpinner(vertexSizeModel);
-    spinnerVertexSize.setMaximumSize(new Dimension(40,16));
-    spinnerVertexSize.setAlignmentX(Component.LEFT_ALIGNMENT);
-    spinnerVertexSize.addChangeListener(new ChangeListener() {
+    spinVertexSize = new JSpinner(vertexSizeModel);
+    spinVertexSize.setMaximumSize(new Dimension(40,16));
+    spinVertexSize.setAlignmentX(Component.LEFT_ALIGNMENT);
+    spinVertexSize.addChangeListener(new ChangeListener() {
       public void stateChanged(ChangeEvent e) {
         int size = vertexSizeModel.getNumber().intValue();
         layer.getLayerStyle().setVertexSize(size);
@@ -242,8 +262,19 @@ public class LayerStylePanel extends JPanel {
       }
     });
 
+    comboVertexSymbol = new JComboBox(vertexSymbolNames);
+    comboVertexSymbol.addActionListener(new ActionListener() {
+      public void actionPerformed(ActionEvent e) {
+        JComboBox cb = (JComboBox)e.getSource();
+        int symType = getVertexSymbol(cb);
+        layer.getLayerStyle().setVertexSymbol(symType);
+        JTSTestBuilder.controller().geometryViewChanged();
+      }
+    });
     
-    addRow("Vertices", cbVertex, btnVertexColor, spinnerVertexSize, cbVertexLabel);
+    comboVertexSymbol.setToolTipText(AppStrings.TIP_STYLE_SYMBOL);
+   
+    addRow("Vertices", cbVertex, btnVertexColor, spinVertexSize, comboVertexSymbol, cbVertexLabel);
     //=============================================
 
     cbStroked = new JCheckBox();
@@ -317,8 +348,31 @@ public class LayerStylePanel extends JPanel {
         JTSTestBuilder.controller().geometryViewChanged();
       }
     });
+    cbOffset = new JCheckBox();
+    cbOffset.setText("Offset");
+    //cbDashed.setToolTipText(AppStrings.STYLE_VERTEX_ENABLE);
+    cbOffset.setAlignmentX(Component.LEFT_ALIGNMENT);
+    cbOffset.addActionListener(new java.awt.event.ActionListener() {
+      public void actionPerformed(ActionEvent e) {
+        if (layer == null) return;
+        layer.getLayerStyle().setOffset(cbOffset.isSelected());
+        JTSTestBuilder.controller().geometryViewChanged();
+      }
+    });
+    offsetSizeModel = new SpinnerNumberModel(LayerStyle.INIT_OFFSET_SIZE, -100, 100, 1);
+    spinOffsetSize = new JSpinner(offsetSizeModel);
+    spinOffsetSize.setMaximumSize(new Dimension(40,16));
+    spinOffsetSize.setAlignmentX(Component.LEFT_ALIGNMENT);
+    spinOffsetSize.addChangeListener(new ChangeListener() {
+      public void stateChanged(ChangeEvent e) {
+        int size = offsetSizeModel.getNumber().intValue();
+        layer.getLayerStyle().setOffsetSize(size);
+        JTSTestBuilder.controller().geometryViewChanged();
+      }
+    });
 
-    addRow("Line", cbStroked, btnLineColor, btnVertexSynch, sliderLineAlpha, spinnerLineWidth, cbDashed);
+    addRow("Line", cbStroked, btnLineColor, btnVertexSynch, sliderLineAlpha, spinnerLineWidth, 
+        cbDashed, cbOffset, spinOffsetSize);
 
     //=============================================
     
@@ -355,31 +409,20 @@ public class LayerStylePanel extends JPanel {
       }
     });
 
-    cbOffset = new JCheckBox();
-    cbOffset.setText("Offset");
-    //cbDashed.setToolTipText(AppStrings.STYLE_VERTEX_ENABLE);
-    cbOffset.setAlignmentX(Component.LEFT_ALIGNMENT);
-    cbOffset.addActionListener(new java.awt.event.ActionListener() {
+    cbSegIndex = new JCheckBox();
+    cbSegIndex.setText("Index");
+    cbSegIndex.setAlignmentX(Component.LEFT_ALIGNMENT);
+    cbSegIndex.addActionListener(new java.awt.event.ActionListener() {
       public void actionPerformed(ActionEvent e) {
         if (layer == null) return;
-        layer.getLayerStyle().setOffset(cbOffset.isSelected());
-        JTSTestBuilder.controller().geometryViewChanged();
-      }
-    });
-    offsetSizeModel = new SpinnerNumberModel(LayerStyle.INIT_OFFSET_SIZE, -100, 100, 1);
-    spinnerOffsetSize = new JSpinner(offsetSizeModel);
-    spinnerOffsetSize.setMaximumSize(new Dimension(40,16));
-    spinnerOffsetSize.setAlignmentX(Component.LEFT_ALIGNMENT);
-    spinnerOffsetSize.addChangeListener(new ChangeListener() {
-      public void stateChanged(ChangeEvent e) {
-        int size = offsetSizeModel.getNumber().intValue();
-        layer.getLayerStyle().setOffsetSize(size);
+        layer.getLayerStyle().setSegIndex(cbSegIndex.isSelected());
         JTSTestBuilder.controller().geometryViewChanged();
       }
     });
+
     
    // Leave on separate line to allow room for dash style
-    addRow("", cbEndpoint, cbOrient, cbStructure, cbOffset, spinnerOffsetSize);
+    addRow("", cbEndpoint, cbOrient, cbStructure, cbSegIndex);
     //=============================================
 
     cbFilled = new JCheckBox();
@@ -467,10 +510,10 @@ public class LayerStylePanel extends JPanel {
        );
     
     labelSizeModel = new SpinnerNumberModel(4, 0, 100, 1);
-    spinnerLabelSize = new JSpinner(labelSizeModel);
-    spinnerLabelSize.setMaximumSize(new Dimension(40,16));
-    spinnerLabelSize.setAlignmentX(Component.LEFT_ALIGNMENT);
-    spinnerLabelSize.addChangeListener(new ChangeListener() {
+    spinLabelSize = new JSpinner(labelSizeModel);
+    spinLabelSize.setMaximumSize(new Dimension(40,16));
+    spinLabelSize.setAlignmentX(Component.LEFT_ALIGNMENT);
+    spinLabelSize.addChangeListener(new ChangeListener() {
       public void stateChanged(ChangeEvent e) {
         int size = labelSizeModel.getNumber().intValue();
         layer.getLayerStyle().setLabelSize(size);
@@ -480,13 +523,14 @@ public class LayerStylePanel extends JPanel {
 
 
     
-    addRow("Label", cbLabel, btnLabelColor, spinnerLabelSize);
+    addRow("Label", cbLabel, btnLabelColor, spinLabelSize);
     
     //=============================================
     
     return containerPanel;
   }
 
+  //-----------------------------------------
   static String[] paletteNames = { "Basic", "Varying", "Rainbow", "Rainbow Random" }; 
 
   private static int getPaletteType(JComboBox comboPal) {
@@ -507,6 +551,22 @@ public class LayerStylePanel extends JPanel {
     comboPal.setSelectedIndex(index);
   }
   
+  //-----------------------------------------
+  static String[] vertexSymbolNames = { "Square", "Square Hollow", "Circle", "Circle Hollow" }; 
+
+  private static int getVertexSymbol(JComboBox combo) {
+    String name = (String)combo.getSelectedItem();
+    
+    for (int i = 0; i < vertexSymbolNames.length; i++) {
+      if (name.equalsIgnoreCase(vertexSymbolNames[i])) return i;
+    }
+    return VertexStyle.SYM_SQUARE_SOLID;
+  }
+  
+  private static void setVertexSymbol(JComboBox combo, int symbolType) {
+    combo.setSelectedIndex(symbolType);
+  }
+  
   protected static Color lineColorFromFill(Color clr) {
     return ColorUtil.saturate(clr,  1);
     //return clr.darker();
