@@ -18,19 +18,16 @@ import java.util.Iterator;
 import org.locationtech.jts.algorithm.Centroid;
 import org.locationtech.jts.algorithm.ConvexHull;
 import org.locationtech.jts.algorithm.InteriorPoint;
-import org.locationtech.jts.geom.util.GeometryCollectionMapper;
-import org.locationtech.jts.geom.util.GeometryMapper;
 import org.locationtech.jts.io.WKTWriter;
-import org.locationtech.jts.operation.IsSimpleOp;
 import org.locationtech.jts.operation.buffer.BufferOp;
+import org.locationtech.jts.operation.buffer.BufferParameters;
 import org.locationtech.jts.operation.distance.DistanceOp;
 import org.locationtech.jts.operation.linemerge.LineMerger;
-import org.locationtech.jts.operation.overlay.OverlayOp;
-import org.locationtech.jts.operation.overlay.snap.SnapIfNeededOverlayOp;
 import org.locationtech.jts.operation.predicate.RectangleContains;
 import org.locationtech.jts.operation.predicate.RectangleIntersects;
 import org.locationtech.jts.operation.relate.RelateOp;
 import org.locationtech.jts.operation.union.UnaryUnionOp;
+import org.locationtech.jts.operation.valid.IsSimpleOp;
 import org.locationtech.jts.operation.valid.IsValidOp;
 import org.locationtech.jts.util.Assert;
 
@@ -402,9 +399,9 @@ public abstract class Geometry
    * tests for this condition and reports <code>false</code> if it is not met.
    * (This is a looser test than checking for validity).
    * <li>Linear rings have the same semantics.
-   * <li>Linear geometries are simple iff they do not self-intersect at points
+   * <li>Linear geometries are simple if they do not self-intersect at points
    * other than boundary points.
-   * <li>Zero-dimensional geometries (points) are simple iff they have no
+   * <li>Zero-dimensional geometries (points) are simple if they have no
    * repeated points.
    * <li>Empty <code>Geometry</code>s are always simple.
    * </ul>
@@ -436,14 +433,19 @@ public abstract class Geometry
   /**
    * Tests whether the set of points covered by this <code>Geometry</code> is
    * empty.
+   * <p>
+   * Note this test is for topological emptiness,
+   * not structural emptiness. 
+   * A collection containing only empty elements is reported as empty.
+   * To check structural emptiness use {@link #getNumGeometries()}.
    *
    *@return <code>true</code> if this <code>Geometry</code> does not cover any points
    */
   public abstract boolean isEmpty();
 
   /**
-   *  Returns the minimum distance between this <code>Geometry</code>
-   *  and another <code>Geometry</code>.
+   * Returns the minimum distance between this <code>Geometry</code>
+   * and another <code>Geometry</code>.
    *
    * @param  g the <code>Geometry</code> from which to compute the distance
    * @return the distance between the geometries
@@ -780,10 +782,10 @@ public abstract class Geometry
    *    <li><code>[0********]</code> (for L/L situations)
    *   </ul>
    * </ul>
-   * For any other combination of dimensions this predicate returns <code>false</code>.
+   * For the A/A and P/P situations this predicate returns <code>false</code>.
    * <p>
    * The SFS defined this predicate only for P/L, P/A, L/L, and L/A situations.
-   * In order to make the relation symmetric,
+   * To make the relation symmetric
    * JTS extends the definition to apply to L/P, A/P and A/L situations as well.
    *
    *@param  g  the <code>Geometry</code> with which to compare this <code>Geometry</code>
@@ -1226,9 +1228,9 @@ public abstract class Geometry
    * The end cap style specifies the buffer geometry that will be
    * created at the ends of linestrings.  The styles provided are:
    * <ul>
-   * <li><code>BufferOp.CAP_ROUND</code> - (default) a semi-circle
-   * <li><code>BufferOp.CAP_BUTT</code> - a straight line perpendicular to the end segment
-   * <li><code>BufferOp.CAP_SQUARE</code> - a half-square
+   * <li>{@link BufferParameters#CAP_ROUND} - (default) a semi-circle
+   * <li>{@link BufferParameters#CAP_FLAT} - a straight line perpendicular to the end segment
+   * <li>{@link BufferParameters#CAP_SQUARE} - a half-square
    * </ul>
 	 * <p>
 	 * The buffer operation always returns a polygonal result. The negative or
@@ -1390,7 +1392,7 @@ public abstract class Geometry
   }
 
   /**
-   * Computes a <code>Geometry </code> representing the closure of the point-set
+   * Computes a <code>Geometry</code> representing the closure of the point-set
    * which is the union of the points in this <code>Geometry</code> which are not
    * contained in the <code>other</code> Geometry,
    * with the points in the <code>other</code> Geometry not contained in this
@@ -1857,6 +1859,9 @@ public abstract class Geometry
 
   private Point createPointFromInternalCoord(Coordinate coord, Geometry exemplar)
   {
+    // create empty point for null input
+    if (coord == null) 
+      return exemplar.getFactory().createPoint();
     exemplar.getPrecisionModel().makePrecise(coord);
     return exemplar.getFactory().createPoint(coord);
   }
