@@ -250,7 +250,7 @@ public abstract class PackedCoordinateSequence
     /**
      * Builds a new packed coordinate sequence
      *
-     * @param coords  an array of <c>double</c> values that contains the ordinate values of the sequence
+     * @param coords  an array of <code>double</code> values that contains the ordinate values of the sequence
      * @param dimension the total number of ordinates that make up a {@link Coordinate} in this sequence.
      * @param measures the number of measure-ordinates each {@link Coordinate} in this sequence has.
      */
@@ -266,7 +266,7 @@ public abstract class PackedCoordinateSequence
     /**
      * Builds a new packed coordinate sequence out of a float coordinate array
      *
-     * @param coords  an array of <c>float</c> values that contains the ordinate values of the sequence
+     * @param coords  an array of <code>float</code> values that contains the ordinate values of the sequence
      * @param dimension the total number of ordinates that make up a {@link Coordinate} in this sequence.
      * @param measures the number of measure-ordinates each {@link Coordinate} in this sequence has.
      */
@@ -414,7 +414,10 @@ public abstract class PackedCoordinateSequence
     public Envelope expandEnvelope(Envelope env)
     {
       for (int i = 0; i < coords.length; i += dimension ) {
-        env.expandToInclude(coords[i], coords[i + 1]);
+        // added to make static code analysis happy
+        if (i + 1 < coords.length) {
+          env.expandToInclude(coords[i], coords[i + 1]);
+        }
       }
       return env;
     }
@@ -433,7 +436,7 @@ public abstract class PackedCoordinateSequence
     /**
      * Constructs a packed coordinate sequence from an array of <code>float</code>s
      *
-     * @param coords  an array of <c>float</c> values that contains the ordinate values of the sequence
+     * @param coords  an array of <code>float</code> values that contains the ordinate values of the sequence
      * @param dimension the total number of ordinates that make up a {@link Coordinate} in this sequence.
      * @param measures the number of measure-ordinates each {@link Coordinate} in this sequence has.
      */
@@ -449,7 +452,7 @@ public abstract class PackedCoordinateSequence
     /**
      * Constructs a packed coordinate sequence from an array of <code>double</code>s
      *
-     * @param coords  an array of <c>double</c> values that contains the ordinate values of the sequence
+     * @param coords  an array of <code>double</code> values that contains the ordinate values of the sequence
      * @param dimension the total number of ordinates that make up a {@link Coordinate} in this sequence.
      * @param measures the number of measure-ordinates each {@link Coordinate} in this sequence has.
      */
@@ -591,7 +594,10 @@ public abstract class PackedCoordinateSequence
     public Envelope expandEnvelope(Envelope env)
     {
       for (int i = 0; i < coords.length; i += dimension ) {
-        env.expandToInclude(coords[i], coords[i + 1]);
+        // added to make static code analysis happy
+        if (i + 1 < coords.length) {
+          env.expandToInclude(coords[i], coords[i + 1]);
+        }
       }
       return env;
     }
