@@ -1,5 +1,3 @@
-
-
 /*
  * Copyright (c) 2016 Vivid Solutions.
  *
@@ -587,11 +585,12 @@ public class TestReader
     public static List getContents(String textFileName) throws FileNotFoundException, IOException {
         List contents = new Vector();
         FileReader fileReader = new FileReader(textFileName);
-        BufferedReader bufferedReader = new BufferedReader(fileReader);
-        String line = bufferedReader.readLine();
-        while (line != null) {
-            contents.add(line);
-            line = bufferedReader.readLine();
+        try(BufferedReader bufferedReader = new BufferedReader(fileReader)){
+            String line = bufferedReader.readLine();
+            while (line != null) {
+                contents.add(line);
+                line = bufferedReader.readLine();
+            }
         }
         return contents;
     }
